# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Devel-CallChecker
Version:	0.009
Release:	1.%{__distinit}%{__distvers}
Summary:	Custom op checking attached to subroutines
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Devel-CallChecker
Source0:	https://cpan.metacpan.org/modules/by-module/Devel/Devel-CallChecker-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::CBuilder) >= 0.15
BuildRequires:	perl(Module::Build)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(DynaLoader::Functions) >= 0.001
BuildRequires:	perl(Exporter)
BuildRequires:	perl(parent)
# Test Suite
BuildRequires:	perl(ExtUtils::ParseXS)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::File) >= 1.03
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl(threads)
BuildRequires:	perl(threads::shared)
BuildRequires:	perl(Thread::Semaphore)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(DynaLoader)
Requires:	perl(DynaLoader::Functions) >= 0.001

%{?perl_default_filter}

%description
This module makes some new features of the Perl 5.14.0 C API available to
XS modules running on older versions of Perl. The features are centered
around the function cv_set_call_checker, which allows XS code to attach a
magical annotation to a Perl subroutine, resulting in resolvable calls to
that subroutine being mutated at compile time by arbitrary C code. This
module makes cv_set_call_checker and several supporting functions
available. (It is possible to achieve the effect of cv_set_call_checker
from XS code on much earlier Perl versions, but it is painful to achieve
without the centralized facility.)

%prep
%setup -q -n Devel-CallChecker-%{version}

%build
perl Build.PL --installdirs=vendor --optimize="%{optflags}"
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
./Build test

%files
%doc Changes README
%{perl_vendorarch}/auto/Devel/
%{perl_vendorarch}/Devel/
%{_mandir}/man3/Devel::CallChecker.3*

%changelog
* Tue Apr 11 2023 Paul Howarth <paul@city-fan.org> - 0.009-1
- Update to 0.009
  - Port to Perl 5.33.1, which defines a PERL_VERSION_GE() macro that clashes
    with the one this module previously had
  - Skip thread tests on some old versions of Perl (around 5.10.0) where a
    core bug makes thread creation violate an internal assertion and causes
    crashes
  - Skip thread tests on pre-5.8.9 Perls where a core bug makes thread creation
    corrupt memory
  - Skip thread tests on pre-5.8.3 Perls where a core bug makes thread
    completion break the global PL_sv_placeholder
  - Put whitespace around C string literals being pasted, for C++11
    compatibility
  - Avoid using C preprocessor directives inside a macro argument list (which
    is not valid)
  - In XS code in the test suite, when croaking, avoid using __FILE__ as part
    of a format string, in case it includes a metacharacter
  - Document the intended scope of this module's backporting effort
  - Fix a documentation wording glitch
  - In XS declare as const some data that never changes
  - Refactor thread tests
  - In XS, refactor Perl version comparisons
  - In XS, rename some macros for better style
  - In XS, better argument parenthesisation in some macros
  - Avoid some compiler warnings
  - In .gitignore, list temporary files produced by test XS compilation
- Use SPDX-format license tag

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 0.008-16
- Perl 5.36 rebuild

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 0.008-13
- Perl 5.34 rebuild

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 0.008-10
- Perl 5.32 rebuild

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.008-7
- Perl 5.30 rebuild

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 0.008-4
- Perl 5.28 rebuild

* Wed Mar 28 2018 Paul Howarth <paul@city-fan.org> - 0.008-3
- ExtUtils::CBuilder needed for build process, not just for tests

* Mon Aug  7 2017 Paul Howarth <paul@city-fan.org> - 0.008-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Update test suite not to rely on . in @INC, which is no longer necessarily
    there from Perl 5.25.7
  - No longer include a Makefile.PL in the distribution
  - In documentation, use four-column indentation for all verbatim material
  - In META.{yml,json}, point to public bug tracker
  - Update op-munging code to the PERL_OP_PARENT-compatible style (though none
    of it is actually used on Perls new enough to support PERL_OP_PARENT)
  - In tests, revise PERL_OP_PARENT reserve definitions to simpler form,
    accommodating only Perl 5.21.11 or later
  - Consistently use THX_ prefix on internal function names

* Mon Jul 17 2017 Paul Howarth <paul@city-fan.org> - 0.007-8
- Import from Fedora

* Mon Jun 05 2017 Jitka Plesnikova <jplesnik@redhat.com> - 0.007-7
- Perl 5.26 rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.007-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sun May 15 2016 Jitka Plesnikova <jplesnik@redhat.com> - 0.007-5
- Perl 5.24 rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.007-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.007-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jun 05 2015 Jitka Plesnikova <jplesnik@redhat.com> - 0.007-2
- Perl 5.22 rebuild

* Mon Mar 23 2015 Petr Pisar <ppisar@redhat.com> - 0.007-1
- 0.007 bump

* Thu Aug 28 2014 Jitka Plesnikova <jplesnik@redhat.com> - 0.006-4
- Perl 5.20 rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.006-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.006-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Sep 23 2013 Petr Pisar <ppisar@redhat.com> - 0.006-1
- 0.006 bump
- This version should be compatible with any binary compatible perl version
  (bug #754159)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.005-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 21 2013 Petr Pisar <ppisar@redhat.com> - 0.005-5
- Perl 5.18 rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.005-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.005-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jun 28 2012 Petr Pisar <ppisar@redhat.com> - 0.005-2
- Perl 5.16 rebuild

* Mon Feb 13 2012 Petr Pisar <ppisar@redhat.com> - 0.005-1
- 0.005 bump

* Thu Feb 02 2012 Petr Pisar <ppisar@redhat.com> - 0.004-1
- 0.004 bump

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.003-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Nov 15 2011 Petr Pisar <ppisar@redhat.com> - 0.003-2
- Rebuild against Perl 5.14.2 (bug #754159)

* Mon Jul 11 2011 Petr Pisar <ppisar@redhat.com> - 0.003-1
- Specfile autogenerated by cpanspec 1.78
- Remove BuildRoot and defattr
